@@ -23,6 +23,7 @@ TEMP = f'{TEMP_FOLDER}/TEMP.txt'
 class ContainerMap:
 
     MAP_FILE_NAME = "map.json"
+    CONTAINER_NAME = ""
     container_client = None
     generator = None
     logger = None
@@ -39,6 +40,7 @@ class ContainerMap:
         conn_string = os.environ[conn_string_name]
         self.container_client = ContainerClient.from_connection_string(
             conn_str=conn_string, container_name=container_name)
+        self.CONTAINER_NAME = container_name
         self.generator = self.container_client.list_blobs()
         self.logger = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO)
@@ -131,6 +133,7 @@ class ContainerMap:
         blob_client = self.container_client.get_blob_client(self.MAP_FILE_NAME)
         self.delete_map()
         blob_client.upload_blob(data=json_content)
+        self.logger(f"Finished writing map to storage account {self.CONTAINER_NAME} at {self.MAP_FILE_NAME}")
 
     def write_map_local(self, map):
         """Creates a local copy of the storage container map
@@ -142,6 +145,7 @@ class ContainerMap:
         json_file = open(self.MAP_FILE_NAME, "w")
         json_file.write(json_content)
         json_file.close()
+        self.logger(f"Finished writing at {os.path.abspath(self.MAP_FILE_NAME)}")
 
     def delete_map(self):
         """Deletes the storage map from the blob storage container if it exists
@@ -347,13 +351,15 @@ class MapReporter:
     STORAGE_MAP = None
     DEPTH = 0
     PREFIX = ""
+    OUTPUT_FILE_NAME = "map.cvs"
 
-    def __init__(self, storage_map, depth=sys.maxsize, prefix=""):
+    def __init__(self, storage_map, depth=sys.maxsize, prefix="", output_file_name="map.csv"):
         self.logger = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO)
         self.STORAGE_MAP = storage_map
         self.DEPTH = depth
         self.PREFIX = prefix.replace('\\', '/')
+        self.OUTPUT_FILE_NAME = output_file_name
         self.logger.info(
             f"### Init complete for map with depth: [{self.DEPTH}]")
 
@@ -398,8 +404,9 @@ class MapReporter:
         self.logger.info(f"### Returning: \n{header_string}\n{info_string}")
         return [header_string, info_string]
 
-    def print_csv(self):
-        self.logger.info("### Printing csv...")
+    def create_csv(self):
+        """Returns formatted text meant to be stored in a csv file"""
+        self.logger.info("### Creating csv...")
         today = datetime.now().strftime("%m-%Y")
         csv_data = (f"Month, Total Bytes, Total Blobs\n{today}, {self.STORAGE_MAP['__Count__']}, {self.STORAGE_MAP['__Size__']}\n\n")
         if len(self.PREFIX) > 0:
@@ -408,3 +415,11 @@ class MapReporter:
             self.STORAGE_MAP, self.DEPTH)
         csv_data += f"\n{content_headers}\n{content_info}"
         return csv_data
+
+    def write_csv_local(self):
+        self.logger.info(f"Writing csv to {self.OUTPUT_FILE_NAME}")
+        csv_data = self.create_csv()
+        file = open(self.OUTPUT_FILE_NAME, "w")
+        file.write(file.write(csv_data))
+        file.close()
+        self.logger(f"Finished writing at {os.path.abspath(self.OUTPUT_FILE_NAME)}")
